@@ -6,13 +6,15 @@
 
 #pragma once
 
+#include <glib.h>
+
 /**
  * JCAT_MAJOR_VERSION:
  *
  * The compile-time major version
  */
 #ifndef JCAT_MAJOR_VERSION
-#define JCAT_MAJOR_VERSION				(0)
+#define JCAT_MAJOR_VERSION (0)
 #endif
 
 /**
@@ -21,7 +23,7 @@
  * The compile-time minor version
  */
 #ifndef JCAT_MINOR_VERSION
-#define JCAT_MINOR_VERSION				(1)
+#define JCAT_MINOR_VERSION (1)
 #endif
 
 /**
@@ -30,7 +32,7 @@
  * The compile-time micro version
  */
 #ifndef JCAT_MICRO_VERSION
-#define JCAT_MICRO_VERSION				(2)
+#define JCAT_MICRO_VERSION (11)
 #endif
 
 /**
@@ -42,8 +44,10 @@
  * Check whether a libjcat version equal to or greater than
  * major.minor.micro.
  */
-#define LIBJCAT_CHECK_VERSION(major,minor,micro)    \
-    (JCAT_MAJOR_VERSION > (major) || \
-     (JCAT_MAJOR_VERSION == (major) && JCAT_MINOR_VERSION > (minor)) || \
-     (JCAT_MAJOR_VERSION == (major) && JCAT_MINOR_VERSION == (minor) && \
-      JCAT_MICRO_VERSION >= (micro)))
+#define LIBJCAT_CHECK_VERSION(major, minor, micro)                                                 \
+	(JCAT_MAJOR_VERSION > (major) ||                                                           \
+	 (JCAT_MAJOR_VERSION == (major) && JCAT_MINOR_VERSION > (minor)) ||                        \
+	 (JCAT_MAJOR_VERSION == (major) && JCAT_MINOR_VERSION == (minor) &&                        \
+	  JCAT_MICRO_VERSION >= (micro)))
+
+const gchar	*jcat_version_string	(void);
